@@ -1,5 +1,5 @@
 """OSEF private types definition."""
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 
 # Standard imports
 from enum import Enum, IntEnum
@@ -79,6 +79,8 @@ class OsefTypes(IntEnum):
     _INTERACTIVE_RESPONSE_BACKGROUND_DATA = 66
     _INTERACTIVE_REQUEST_PINGPONG = 67
     _INTERACTIVE_RESPONSE_PINGPONG = 68
+    _HEIGHT_MAP = 69
+    _HEIGHT_MAP_POINTS = 70
 
 
 class OsefKeys(Enum):
@@ -349,6 +351,7 @@ class OsefKeys(Enum):
     - none or one:     Zones Objects Binding          (ZONES_OBJECTS_BINDING) [DEPRECATED USAGE]
     - none or one:     Zones Objects Binding 32 Bits  (ZONES_OBJECTS_BINDING_32_BITS)
     - none or one:     Smoothed Pose                  (SMOOTHED_POSE)
+    - none or one:     Height Map                     (HEIGHT_MAP)
     """
     SCAN_FRAME = "scan_frame"
 
@@ -623,7 +626,7 @@ class OsefKeys(Enum):
       it remains the same throughout the tracking phase.
     When used as leaf of Augmented Cloud:
     - The number of elements of the array is equal to the Number of Points (type 2).
-    - Each specified ID indicates to witch object the point belongs.
+    - Each specified ID indicates to which object the point belongs.
     - The special value 0 is used to mean 'no object'.
       For instance, if the object ID of a point is 0,
       it means that this point does not belong to any object.
@@ -708,7 +711,7 @@ class OsefKeys(Enum):
     * single-precision floats Rxx, Rxy, Rxz, Ryx, Ryy, Ryz, Rzx, Rzy and Rzz represent the rotation matrix R defining
     the orientation.
     **Coordinate Frame**:
-    Absolute/world, witch is:
+    Absolute/world, which is:
     - Single-LiDAR: On-Ground LiDAR Coordinate Frame.
     - Multi-LiDARs: Map Coordinate Frame.
     """
@@ -812,6 +815,35 @@ class OsefKeys(Enum):
     """
     _INTERACTIVE_RESPONSE_PINGPONG = "interactive_response_pingpong"
 
+    """
+    Height Map
+    Height map of a configurable zone of interest.
+    **Output when**: generated by height_map app.
+    """
+    _HEIGHT_MAP = "height_map"
+
+    """
+    Height Map Points
+    Points that define the height map and provide the height data.
+    The height map is defined as a two-dimensional horizontal grid in the Lidar frame, with given dimensions and number
+    of cells.
+    The properties of the height map, such as size, number of cells, height offset, etc, are defined by the height_map
+    app configuration.
+    Every points of the augmented cloud are used to build the height map, with no distinction if it is a point of the
+    ground, a motion point or any other flag.
+    A point of the cloud is associated with a cell if its projected point on the grid is in the cell.
+    The height map provides one height information per cell, the height value depends on the way it is computed by the
+    app (a cell vith no points will have a nan value).
+    The Height Map Points is defined as an array of points, with one point per cell of the height map.
+    The x and y coordinates represent the center of the cell in the Lidar frame, the third value is the height of the
+    cell computed by the app with the points of the cell.
+    **Format**: Contains list of Cartesian single-precision float coordinates, three per point:
+    * x : meters, range [ -inf .. +inf ]
+    * y : meters, range [ -inf .. +inf ]
+    * z : meters, range [ -inf .. +inf ]
+    """
+    _HEIGHT_MAP_POINTS = "height_map_points"
+
 
 class ClassId(IntEnum):
     """Tracked object class ID"""
@@ -820,8 +852,8 @@ class ClassId(IntEnum):
     PERSON = 1
     LUGGAGE = 2
     TROLLEY = 3
-    TRUCK = 4
-    BUS = 5
+    DEPRECATED = 4
+    TRUCK = 5
     CAR = 6
     VAN = 7
     TWO_WHEELER = 8
