@@ -397,6 +397,16 @@ outsight_types = {
         OsefKeys._SMOOTHED_POSE.value,
         LeafInfo(_unpackers._pose_array_unpacker, _packers._pose_array_packer),
     ),
+    OsefTypes._HEIGHT_MAP.value: TypeInfo(
+        OsefKeys._HEIGHT_MAP.value, InternalNodeInfo(dict)
+    ),
+    OsefTypes._HEIGHT_MAP_POINTS.value: TypeInfo(
+        OsefKeys._HEIGHT_MAP_POINTS.value,
+        LeafInfo(
+            _unpackers._get_array_unpacker(np.dtype(np.float32), 3),
+            _packers._array_packer,
+        ),
+    ),
 }
 
 
